﻿-- Author      : RisM
-- Create Date : 11/29/2009 2:23:42 AM

local SpeakinSpell = LibStub("AceAddon-3.0"):GetAddon("SpeakinSpell")
local L				= LibStub("AceLocale-3.0"):GetLocale("SpeakinSpell",					false)

SpeakinSpell:PrintLoading("gui/generaloptions.lua")


-------------------------------------------------------------------------------
-- GUI LAYOUT - NETWORK DATA SHARING
-------------------------------------------------------------------------------

SpeakinSpell.OptionsGUI.args.Network = {
	order = 1,
	type = "group",
	name = L["Data Sharing"],
	desc = L["Share information with other SpeakinSpell users"],
	args = {
		-----------------------
		Header = {
			order = 1,
			type = "header",
			name = function()
				SpeakinSpell:SetLastPageViewed( "Network", L["Data Sharing"] )
				return L["Data Sharing"]
			end,
		},
		Caption = {
			order = 2,
			type = "description",
			name = L["Share information with other SpeakinSpell users."],
		},
		
		-----------------------
		EnableNetwork = {
			order = 3,
			type = "toggle",
			name = "Enable Network Communications",
			width = "full",
			desc = "Allows blocking any and all network communications with other SpeakinSpell users. This is an account-wide option.",
			get = function() return SpeakinSpellSavedDataForAll.Networking.EnableNetwork end,
			set = function(_,value)
				SpeakinSpellSavedDataForAll.Networking.EnableNetwork = value
				if value then
					SpeakinSpell:Network_Init()
				else
					SpeakinSpell:Network_Disable()
				end
			end,
		},
		ShowHideGroup = {
			order = 5,
			type = "group",
			name = L["Networking Options and Commands"],
			desc = "", -- not used
			hidden = function()
				return not SpeakinSpellSavedDataForAll.Networking.EnableNetwork
			end,
			guiInline = true,
			args = {
				ShowCommTraffic = {
					order = 1,
					type = "toggle",
					width = "full",
					name = L["Show Comm Traffic"],
					desc = L["Show data sharing communication progress messages in the chat"],
					get = function() return SpeakinSpellSavedDataForAll.Networking.ShowCommTraffic end,
					set = function(_,value) SpeakinSpellSavedDataForAll.Networking.ShowCommTraffic = value end,
				},
				ShowTransferProgress = {
					order = 2,
					type = "toggle",
					width = "full",
					name = L["Show Transfer Progress"],
					desc = L["Show outbound data transfer progress"],
					get = function() return SpeakinSpellSavedDataForAll.Networking.ShowTransferProgress end,
					set = function(_,value) SpeakinSpellSavedDataForAll.Networking.ShowTransferProgress = value end,
					hidden = function() return not SpeakinSpellSavedDataForAll.Networking.ShowCommTraffic end,
				},
				Versions = {
					order = 10,
					type = "group",
					guiInline = true,
					name = L["New Version Checks"],
					desc = "", -- not used
					args = {
						Info = {
							order = 1,
							type = "description",
							name = function()
								local name = string.format( 
									L["You are running v%s\nNewest version detected: v%s"], 
									SpeakinSpell.CURRENT_VERSION, SpeakinSpell.RuntimeData.Networking.NewestVersion )
								if SpeakinSpell.CURRENT_VERSION < SpeakinSpell.RuntimeData.Networking.NewestVersion then
									name = name .. L["\nAn update is available!"] --TODO: ? color code this, make it green or something ?
								end
								return name
							end,
						},
						AutoVersionChecks = {
							order = 2,
							type = "toggle",
							width = "full",
							name = L["Automatically check for new versions"],
							desc = L["Enable automatic checks for new upgraded versions of SpeakinSpell"],
							get = function() return SpeakinSpellSavedDataForAll.Networking.AutoVersionChecks end,
							set = function(_,value) SpeakinSpellSavedDataForAll.Networking.AutoVersionChecks = value end,
						},
						DoVersionCheck = {
							order = 3,
							type = "execute",
							name = L["Check Now"],
							desc = L["Check for an update"],
							func = function()
								SpeakinSpell:Network_SendVersionRequest()
								--SpeakinSpell:Print("New version check requested.")
								--SpeakinSpell:Print("If a newer client responds, a message will show in chat")
							end,
						},
					},
				},
				NewEvents = {
					order = 11,
					type = "group",
					guiInline = true,
					name = L["New Events Detected"],
					desc = "", -- not used
					args = {
						AutoSyncNewEvents = {
							order = 2,
							type = "toggle",
							width = "full",
							name = L["Auto-Sync New Events List"],
							desc = L["Enable automatic synchronization of the new events list shown under the Create New GUI (/ss create)"],
							get = function() return SpeakinSpellSavedDataForAll.Networking.AutoSyncNewEvents end,
							set = function(_,value) SpeakinSpellSavedDataForAll.Networking.AutoSyncNewEvents = value end,
						},
						BroadcastNewEvents = {
							order = 2,
							type = "execute",
							name = L["Sync New Events List"],
							desc = L[ [[Synchronize your list of detected events from the "/ss create" GUI with other SS users]] ],
							func = function()
								SpeakinSpell:Network_SendNewEvents(nil,true,nil)
								--SpeakinSpell:Print(L["New event list sent."])
								--SpeakinSpell:Print(L[ [[Other instances of SS will reply with any new event info that you do not have, increasing your options under "/ss create".]] ])
							end,
						},
					},
				},
				EventTable = {
					order = 12,
					type = "group",
					guiInline = true,
					name = L["Event Table"],
					desc = "", -- not used
					args = {
						ShareSpeeches = {
							order = 1,
							type = "toggle",
							name = L["Share my speeches"],
							desc = L["If you allow sharing your speeches, other SS users may silently request them from you."],
							get = function() return SpeakinSpellSavedDataForAll.Networking.ShareSpeeches end,
							set = function(_, value) SpeakinSpellSavedDataForAll.Networking.ShareSpeeches = value end,
						},
						AutoShare = {
							order = 2,
							type = "toggle",
							name = L["Auto-share at startup"],
							desc = L["Automatically broadcast your speeches to other SpeakinSpell users"],
							get = function() return SpeakinSpellSavedDataForAll.Networking.AutoShareSpeeches end,
							set = function(_, value) SpeakinSpellSavedDataForAll.Networking.AutoShareSpeeches = value end,
							hidden = function() return not SpeakinSpellSavedDataForAll.Networking.ShareSpeeches end,
						},
						CollectSpeeches = {
							order = 3,
							type = "toggle",
							name = L["Collect Speeches"],
							desc = L[ 
[[Allow collecting and storing speeches that have been shared by other SpeakinSpell users.

You can browse these collected speeches through the Import New Data GUI (/ss import)]] ],
							get = function() return SpeakinSpellSavedDataForAll.Networking.CollectSpeeches end,
							set = function(_, value) SpeakinSpellSavedDataForAll.Networking.CollectSpeeches = value end,
						},
						BroadcastSpeeches = {
							order = 4,
							type = "execute",
							width = "full",
							name = L["Broadcast My Speeches"],
							desc = L["Share your speeches with your guild, party, and raid"],
							func = function()
								SpeakinSpell:Network_SendEventTable(nil)
								--SpeakinSpell:Print("Event Table has been shared with guild, party, and raid.")
							end,
						},
						SendToTarget = {
							order = 5,
							type = "execute",
							width = "full",
							name = L["Send Speeches to <target>"],
							desc = L["Share your speeches with your selected target."],
							func = function()
								local target = UnitName("target")
								if not (target and UnitIsFriend("player",target)) then
									SpeakinSpell:Print( L["Invalid target"] )
									return
								end
								SpeakinSpell:Network_SendEventTable( target )
								--SpeakinSpell:Print( string.format( L["Event Table has been shared with %s"], target ) )
							end,
						},
					},
				},
			},
		},
	},
}


-------------------------------------------------------------------------------
-- OPTIONS GUI FUNCTIONS - NETWORK DATA SHARING
-------------------------------------------------------------------------------
-- all simple enough to be inline above
